Crate binmod_mdk_macros

Crate binmod_mdk_macros 

Attribute Macros

host_fns
This macro is used to define the expected host functions that are accessible to the module. It takes an optional namespace argument to specify the namespace of the host functions. If not provided, it defaults to “env”.
mod_fn
This macro is used to define a module function for the ABI. It takes an optional name argument to specify the exported function name.